fluent_pages.extensions
=======================

.. automodule:: fluent_pages.extensions

The ``PageTypePlugin`` class
----------------------------

.. autoclass:: fluent_pages.extensions.PageTypePlugin
   :members:

The ``PageTypePool`` class
--------------------------

.. autoclass:: fluent_pages.extensions.PageTypePool
   :members:

The ``page_type_pool`` attribute
--------------------------------

.. attribute:: fluent_pages.extensions.page_type_pool

    The global plugin pool, a instance of the :class:`PluginPool` class.

Other classes
-------------

.. autoexception:: fluent_pages.extensions.PageTypeAlreadyRegistered

.. autoexception:: fluent_pages.extensions.PageTypeNotFound

